"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
exports.__esModule = true;
var common_utils_1 = require("../utils/common-utils");
var config_1 = require("../config");
var const_1 = require("../const");
var MessageHandler = /** @class */ (function () {
    function MessageHandler(TUIChatService) {
        this.TUIChatService = TUIChatService;
        this.userShowNameMap = new Map();
        this.requestedUserMap = new Map();
    }
    MessageHandler.prototype.getEngine = function () {
        return this.TUIChatService.getEngine();
    };
    /**
     * 国际化翻译
     * @param {string} text 待翻译的文本
     * @returns {string}
    */
    MessageHandler.prototype.t = function (text) {
        return this.getEngine().TUITranslate.t(text);
    };
    MessageHandler.prototype.handleTextMessage = function (message) {
        var ret = {
            text: this.decodeText(message.payload)
        };
        return ret;
    };
    MessageHandler.prototype.handleFaceMessage = function (message) {
        var ret = {
            name: '',
            url: '',
            type: ''
        };
        // 自定义 face 表情图片名称必须带 @custom 标识，比如： '@custom_test.png'
        if (message.payload.data.indexOf('@custom') > -1) {
            ret.name = message.payload.data;
            ret.type = 'custom';
            return ret;
        }
        ret.name = message.payload.data.indexOf('@2x') < 0 ? message.payload.data + "@2x" : message.payload.data;
        ret.url = "" + config_1.BASEURL.face + ret.name + ".png";
        return ret;
    };
    MessageHandler.prototype.handleLocationMessage = function (message) {
        var ret = {
            lon: '',
            lat: '',
            href: '',
            url: '',
            description: ''
        };
        ret.lon = message.payload.longitude.toFixed(6);
        ret.lat = message.payload.latitude.toFixed(6);
        ret.href = config_1.BASEURL.mapHref + "pointx=" + ret.lon + "&pointy=" + ret.lat + "&name=" + message.payload.description;
        ret.url = config_1.BASEURL.mapUrl + "center=" + ret.lat + "," + ret.lon + "&zoom=10&size=300*150&maptype=roadmap&markers=size:large|color:0xFFCCFF|label:k|" + ret.lat + "," + ret.lon + "&key=UBNBZ-PTP3P-TE7DB-LHRTI-Y4YLE-VWBBD";
        ret.description = message.payload.description;
        return ret;
    };
    MessageHandler.prototype.handleImageMessage = function (message) {
        var cacheUrl = this.getEngine().TUIStore.getData(const_1.StoreName.CHAT, "cacheMap").get(message.ID);
        return {
            url: cacheUrl !== null && cacheUrl !== void 0 ? cacheUrl : message.payload.imageInfoArray[0].url,
            width: message.payload.imageInfoArray[0].width,
            height: message.payload.imageInfoArray[0].height
        };
    };
    MessageHandler.prototype.handleAudioMessage = function (message) {
        var cacheUrl = this.getEngine().TUIStore.getData(const_1.StoreName.CHAT, "cacheMap").get(message.ID);
        return {
            url: cacheUrl !== null && cacheUrl !== void 0 ? cacheUrl : message.payload.url,
            second: message.payload.second
        };
    };
    MessageHandler.prototype.handleVideoMessage = function (message) {
        var chatEngine = this.getEngine();
        var cacheMap = chatEngine.TUIStore.getData(const_1.StoreName.CHAT, "cacheMap");
        var cacheVideoUrl = cacheMap.get(message.ID);
        var cacheSnapShotUrl = cacheMap.get(message.ID + '_S');
        return {
            url: cacheVideoUrl !== null && cacheVideoUrl !== void 0 ? cacheVideoUrl : message.payload.videoUrl,
            snapshotUrl: cacheSnapShotUrl !== null && cacheSnapShotUrl !== void 0 ? cacheSnapShotUrl : message.payload.snapshotUrl,
            snapshotWidth: message.payload.snapshotWidth,
            snapshotHeight: message.payload.snapshotHeight
        };
    };
    MessageHandler.prototype.handleFileMessage = function (message) {
        var cacheUrl = this.getEngine().TUIStore.getData(const_1.StoreName.CHAT, "cacheMap").get(message.ID);
        return {
            url: cacheUrl !== null && cacheUrl !== void 0 ? cacheUrl : message.payload.fileUrl,
            name: message.payload.fileName,
            size: common_utils_1.formateFileSize(message.payload.fileSize)
        };
    };
    MessageHandler.prototype.handleCustomMessage = function (message) {
        var _a;
        var createGroupText = this.handleCreateGroupCustomMessage(message);
        return {
            custom: this.handleCallKitSignaling(message) || createGroupText || ((_a = message === null || message === void 0 ? void 0 : message.payload) === null || _a === void 0 ? void 0 : _a.extension) || "" + this.t('TUIChat.[自定义消息]'),
            businessID: createGroupText ? 'group_create' : ''
        };
    };
    MessageHandler.prototype.handleMergeMessage = function (message) {
        return __assign({}, message.payload);
    };
    MessageHandler.prototype.handleGroupTipsMessage = function (message) {
        var _this = this;
        var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m;
        var chatEngine = this.getEngine();
        var ret = {
            text: ''
        };
        // 优先取 nick，nick 不存在时取 userID，以下逻辑是为兼容不同群提示消息的处理
        var showName = (message === null || message === void 0 ? void 0 : message.nick) || ((_b = (_a = message === null || message === void 0 ? void 0 : message.payload) === null || _a === void 0 ? void 0 : _a.userIDList) === null || _b === void 0 ? void 0 : _b.join(','));
        if (((_d = (_c = message === null || message === void 0 ? void 0 : message.payload) === null || _c === void 0 ? void 0 : _c.memberList) === null || _d === void 0 ? void 0 : _d.length) > 0) {
            showName = '';
            (_f = (_e = message === null || message === void 0 ? void 0 : message.payload) === null || _e === void 0 ? void 0 : _e.memberList) === null || _f === void 0 ? void 0 : _f.map(function (user) {
                var _showName = (user === null || user === void 0 ? void 0 : user.nick) || (user === null || user === void 0 ? void 0 : user.userID);
                showName += _this.substringByLength(_showName) + ",";
                return user;
            });
            showName = showName === null || showName === void 0 ? void 0 : showName.slice(0, -1);
        }
        switch (message.payload.operationType) {
            case chatEngine.TYPES.GRP_TIP_MBR_JOIN:
                ret.text = showName + " " + this.t('message.tip.加入群组');
                break;
            case chatEngine.TYPES.GRP_TIP_MBR_QUIT:
                ret.text = this.t('message.tip.群成员') + "\uFF1A" + ((_m = (_j = (_h = (_g = message.payload) === null || _g === void 0 ? void 0 : _g.operatorInfo) === null || _h === void 0 ? void 0 : _h.nickName) !== null && _j !== void 0 ? _j : (_l = (_k = message.payload) === null || _k === void 0 ? void 0 : _k.operatorInfo) === null || _l === void 0 ? void 0 : _l.userID) !== null && _m !== void 0 ? _m : "") + " " + this.t('message.tip.退出群组');
                break;
            case chatEngine.TYPES.GRP_TIP_MBR_KICKED_OUT:
                ret.text = this.t('message.tip.群成员') + "\uFF1A" + showName + " " + this.t('message.tip.被') + this.t('message.tip.踢出群组');
                break;
            case chatEngine.TYPES.GRP_TIP_MBR_SET_ADMIN:
                ret.text = this.t('message.tip.群成员') + "\uFF1A" + showName + " " + this.t('message.tip.成为管理员');
                break;
            case chatEngine.TYPES.GRP_TIP_MBR_CANCELED_ADMIN:
                ret.text = this.t('message.tip.群成员') + "\uFF1A" + showName + " " + this.t('message.tip.被撤销管理员');
                break;
            case chatEngine.TYPES.GRP_TIP_GRP_PROFILE_UPDATED:
                ret.text = this.handleGroupProfileUpdated(message);
                break;
            case chatEngine.TYPES.GRP_TIP_MBR_PROFILE_UPDATED:
                for (var _i = 0, _o = message.payload.memberList; _i < _o.length; _i++) {
                    var member = _o[_i];
                    if (member.muteTime > 0) {
                        ret.text = this.t('message.tip.群成员') + "\uFF1A" + showName + " " + this.t('message.tip.被禁言');
                    }
                    else {
                        ret.text = this.t('message.tip.群成员') + "\uFF1A" + showName + " " + this.t('message.tip.被取消禁言');
                    }
                }
                break;
            default:
                ret.text = "[" + this.t('message.tip.群提示消息') + "]";
                break;
        }
        return ret;
    };
    MessageHandler.prototype.handleGroupSystemMessage = function (message) {
        var groupName = message.payload.groupProfile.name || message.payload.groupProfile.groupID;
        var ret = {
            text: ''
        };
        switch (message.payload.operationType) {
            case 1:
                ret.text = message.payload.operatorID + " " + this.t('message.tip.申请加入群组') + "\uFF1A" + groupName;
                break;
            case 2:
                ret.text = this.t('message.tip.成功加入群组') + "\uFF1A" + groupName;
                break;
            case 3:
                ret.text = this.t('message.tip.申请加入群组') + "\uFF1A" + groupName + " " + this.t('message.tip.被拒绝');
                break;
            case 4:
                ret.text = "" + this.t('message.tip.你被管理员') + message.payload.operatorID + " " + this.t('message.tip.踢出群组') + "\uFF1A" + groupName;
                break;
            case 5:
                ret.text = this.t('message.tip.群') + "\uFF1A" + groupName + " " + this.t('message.tip.被') + " " + message.payload.operatorID + " " + this.t('message.tip.解散');
                break;
            case 6:
                ret.text = message.payload.operatorID + " " + this.t('message.tip.创建群') + "\uFF1A" + groupName;
                break;
            case 7:
                ret.text = message.payload.operatorID + " " + this.t('message.tip.邀请你加群') + "\uFF1A" + groupName;
                break;
            case 8:
                ret.text = this.t('message.tip.你退出群组') + "\uFF1A" + groupName;
                break;
            case 9:
                ret.text = "" + this.t('message.tip.你被') + message.payload.operatorID + " " + this.t('message.tip.设置为群') + "\uFF1A" + groupName + " " + this.t('message.tip.的管理员');
                break;
            case 10:
                ret.text = "" + this.t('message.tip.你被') + message.payload.operatorID + " " + this.t('message.tip.撤销群') + "\uFF1A" + groupName + " " + this.t('message.tip.的管理员身份');
                break;
            case 12:
                ret.text = message.payload.operatorID + " " + this.t('message.tip.邀请你加群') + "\uFF1A" + groupName;
                break;
            case 13:
                ret.text = message.payload.operatorID + " " + this.t('message.tip.同意加群') + "\uFF1A" + groupName;
                break;
            case 14:
                ret.text = message.payload.operatorID + " " + this.t('message.tip.拒接加群') + "\uFF1A" + groupName;
                break;
            case 255:
                ret.text = this.t('message.tip.自定义群系统通知') + ": " + message.payload.userDefinedField;
                break;
            default:
                ret.text = '未解析的群系统通知';
                break;
        }
        return ret;
    };
    MessageHandler.prototype.handleCallKitSignaling = function (message) {
        var _this = this;
        var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k;
        var callMessage = common_utils_1.JSONToObject(message.payload.data);
        if ((callMessage === null || callMessage === void 0 ? void 0 : callMessage.businessID) !== 1) {
            return '';
        }
        var objectData = common_utils_1.JSONToObject(callMessage === null || callMessage === void 0 ? void 0 : callMessage.data);
        var userID = message.fromAccount || message.from; // 取 message.fromAccount 兼容会话 lastMsg
        var friendRemark = this.getEngine().TUIFriend.getFriendRemark([userID]);
        var myUserID = this.getEngine().getMyUserID();
        var messageSender = friendRemark[userID] || message.nameCard || message.nick || userID;
        messageSender = this.substringByLength(messageSender);
        switch (callMessage === null || callMessage === void 0 ? void 0 : callMessage.actionType) {
            case 1: {
                if (((_a = objectData === null || objectData === void 0 ? void 0 : objectData.data) === null || _a === void 0 ? void 0 : _a.cmd) === 'audioCall' || ((_b = objectData === null || objectData === void 0 ? void 0 : objectData.data) === null || _b === void 0 ? void 0 : _b.cmd) === 'videoCall') {
                    if (callMessage === null || callMessage === void 0 ? void 0 : callMessage.groupID) {
                        return messageSender + " " + this.t('message.custom.发起通话');
                    }
                }
                if (((_c = objectData === null || objectData === void 0 ? void 0 : objectData.data) === null || _c === void 0 ? void 0 : _c.cmd) === 'hangup') {
                    if (callMessage === null || callMessage === void 0 ? void 0 : callMessage.groupID) {
                        return "" + this.t('message.custom.通话结束');
                    }
                    return this.t('message.custom.通话时长') + "\uFF1A" + common_utils_1.formatTime(objectData === null || objectData === void 0 ? void 0 : objectData.call_end);
                }
                if (((_d = objectData === null || objectData === void 0 ? void 0 : objectData.data) === null || _d === void 0 ? void 0 : _d.cmd) === 'switchToAudio') {
                    return "" + this.t('message.custom.切换语音通话');
                }
                if (((_e = objectData === null || objectData === void 0 ? void 0 : objectData.data) === null || _e === void 0 ? void 0 : _e.cmd) === 'switchToVideo') {
                    return "" + this.t('message.custom.切换视频通话');
                }
                // CDM 异常时【发起通话】作为默认返回值
                return "" + this.t('message.custom.发起通话');
            }
            case 2:
                if (callMessage === null || callMessage === void 0 ? void 0 : callMessage.groupID) {
                    return messageSender + " " + this.t('message.custom.取消通话');
                }
                if (this.isOldUIKit('message.custom.已取消')) {
                    return this.t('message.custom.取消通话');
                }
                if ((callMessage === null || callMessage === void 0 ? void 0 : callMessage.inviter) === myUserID) {
                    return this.t('message.custom.已取消');
                }
                return this.t('message.custom.对方已取消');
            case 3:
                if (((_f = objectData === null || objectData === void 0 ? void 0 : objectData.data) === null || _f === void 0 ? void 0 : _f.cmd) === 'switchToAudio') {
                    return "" + this.t('message.custom.切换语音通话');
                }
                if (((_g = objectData === null || objectData === void 0 ? void 0 : objectData.data) === null || _g === void 0 ? void 0 : _g.cmd) === 'switchToVideo') {
                    return "" + this.t('message.custom.切换视频通话');
                }
                if (callMessage === null || callMessage === void 0 ? void 0 : callMessage.groupID) {
                    return messageSender + " " + this.t('message.custom.已接听');
                }
                return this.t('message.custom.已接听');
            case 4:
                if (callMessage === null || callMessage === void 0 ? void 0 : callMessage.groupID) {
                    return messageSender + " " + this.t('message.custom.拒绝通话');
                }
                if (this.isOldUIKit('message.custom.已拒绝')) {
                    return this.t('message.custom.拒绝通话');
                }
                if ((objectData === null || objectData === void 0 ? void 0 : objectData.line_busy) === 'line_busy' || (objectData === null || objectData === void 0 ? void 0 : objectData.data.message) === 'lineBusy') {
                    if ((callMessage === null || callMessage === void 0 ? void 0 : callMessage.inviter) === myUserID) {
                        return this.t('message.custom.对方忙线中');
                    }
                    return this.t('message.custom.忙线未接听');
                }
                if ((callMessage === null || callMessage === void 0 ? void 0 : callMessage.inviter) === myUserID) {
                    return this.t('message.custom.对方已拒绝');
                }
                return this.t('message.custom.已拒绝');
            case 5:
                if (((_h = objectData === null || objectData === void 0 ? void 0 : objectData.data) === null || _h === void 0 ? void 0 : _h.cmd) === 'switchToAudio') {
                    return "" + this.t('message.custom.切换语音通话');
                }
                if (((_j = objectData === null || objectData === void 0 ? void 0 : objectData.data) === null || _j === void 0 ? void 0 : _j.cmd) === 'switchToVideo') {
                    return "" + this.t('message.custom.切换视频通话');
                }
                if (callMessage === null || callMessage === void 0 ? void 0 : callMessage.groupID) {
                    // 群通话主叫超时
                    if (userID === (callMessage === null || callMessage === void 0 ? void 0 : callMessage.inviter)) {
                        this.handleCallkitTimeoutSignaling(callMessage.inviteeList);
                        var inviteeList_1 = '';
                        (_k = callMessage.inviteeList) === null || _k === void 0 ? void 0 : _k.forEach(function (inviteeUserID) {
                            var showName = _this.userShowNameMap.get(inviteeUserID) || inviteeUserID;
                            inviteeList_1 += _this.substringByLength(showName) + "\u3001";
                        });
                        inviteeList_1 = inviteeList_1.substring(0, inviteeList_1.lastIndexOf('、'));
                        return inviteeList_1 + " " + this.t('message.custom.无应答');
                    }
                    // 群通话被叫超时
                    return messageSender + " " + this.t('message.custom.无应答');
                }
                if (this.isOldUIKit('message.custom.对方无应答')) {
                    return this.t('message.custom.无应答');
                }
                if ((callMessage === null || callMessage === void 0 ? void 0 : callMessage.inviter) === myUserID) {
                    return this.t('message.custom.对方无应答');
                }
                return this.t('message.custom.超时无应答');
            default:
                return '';
        }
    };
    MessageHandler.prototype.handleCreateGroupCustomMessage = function (message) {
        var text;
        var data = common_utils_1.JSONToObject(message.payload.data);
        if ((data === null || data === void 0 ? void 0 : data.businessID) === 'group_create') {
            text = data.opUser + " " + data.content;
        }
        return text;
    };
    /**
     * 解析文本消息
     * @param {Object} payload 消息 payload 载体
     * @param {String} payload.text 消息内容
     * @returns {String}
    */
    MessageHandler.prototype.decodeText = function (payload) {
        var renderDom = [];
        // 文本消息
        var temp = payload.text;
        var left = -1;
        var right = -1;
        while (temp !== '') {
            left = temp.indexOf('[');
            right = temp.indexOf(']');
            switch (left) {
                case 0:
                    if (right === -1) {
                        renderDom.push({
                            name: 'text',
                            text: temp
                        });
                        temp = '';
                    }
                    else {
                        var emojiKey = temp.slice(0, right + 1);
                        // 自定义 emoji 表情 emojiKey 必须带 @custom 标识，比如：'[@custom_Smile]'
                        if (emojiKey.indexOf('@custom') > -1) {
                            renderDom.push({
                                name: 'img',
                                src: '',
                                type: 'custom',
                                emojiKey: emojiKey
                            });
                            temp = temp.substring(right + 1);
                        }
                        else if (config_1.BASIC_EMOJI_URL_MAPPING[emojiKey]) {
                            renderDom.push({
                                name: 'img',
                                src: config_1.BASEURL.emoji + config_1.BASIC_EMOJI_URL_MAPPING[emojiKey],
                                emojiKey: emojiKey
                            });
                            temp = temp.substring(right + 1);
                        }
                        else {
                            renderDom.push({
                                name: 'text',
                                text: '['
                            });
                            temp = temp.slice(1);
                        }
                    }
                    break;
                case -1:
                    renderDom.push({
                        name: 'text',
                        text: temp
                    });
                    temp = '';
                    break;
                default:
                    renderDom.push({
                        name: 'text',
                        text: temp.slice(0, left)
                    });
                    temp = temp.substring(left);
                    break;
            }
        }
        return renderDom;
    };
    /**
     * 解析群资料更新内容
     * @param {Message} message 群提示消息
     * @returns {String}
    */
    MessageHandler.prototype.handleGroupProfileUpdated = function (message) {
        var nick = message.nick, payload = message.payload;
        var newGroupProfile = payload.newGroupProfile, memberList = payload.memberList, operatorID = payload.operatorID;
        var text = '';
        var showName = nick || operatorID;
        var key = Object.keys(newGroupProfile)[0];
        switch (key) {
            case 'muteAllMembers':
                if (newGroupProfile[key]) {
                    text = this.t('message.tip.管理员') + " " + showName + " " + this.t('message.tip.开启全员禁言');
                }
                else {
                    text = this.t('message.tip.管理员') + " " + showName + " " + this.t('message.tip.取消全员禁言');
                }
                break;
            case 'groupCustomField':
                var childKey = newGroupProfile.groupCustomField[0].key;
                switch (childKey) {
                    case 'ownerID':
                        text = (memberList[0].nick || memberList[0].userID) + " " + this.t('message.tip.成为新的群主');
                        break;
                    case 'name':
                        text = showName + " " + this.t('message.tip.修改群名为') + " " + newGroupProfile.groupCustomField[0].value;
                        break;
                    case 'notification':
                        if (this.isOldUIKit('message.tip.把群公告修改为')) {
                            text = showName + " " + this.t('message.tip.发布新公告');
                        }
                        else {
                            text = showName + " " + this.t('message.tip.把群公告修改为') + " \"" + newGroupProfile.groupCustomField[0].value + "\"";
                        }
                        break;
                    case 'joinOption':
                        text = showName + " " + '修改进群选项';
                        break;
                    case 'inviteOption':
                        text = showName + " " + '修改邀请进群选项';
                        break;
                }
                break;
        }
        return text;
    };
    MessageHandler.prototype.handleCallkitTimeoutSignaling = function (inviteeList) {
        var _this = this;
        if (inviteeList === void 0) { inviteeList = []; }
        if (inviteeList.length === 0) {
            return;
        }
        var friendRemarkResult = this.getEngine().TUIFriend.getFriendRemark(inviteeList);
        var userIDList = [];
        inviteeList.forEach(function (userID) {
            var showName = friendRemarkResult[userID];
            if (showName) {
                _this.userShowNameMap.set(userID, showName);
            }
            else if (!_this.requestedUserMap.has(userID)) {
                userIDList.push(userID);
                _this.requestedUserMap.set(userID, 1);
            }
        });
        // 注意：按照一条主叫超时信令请求一次处理，先不用截流处理
        if (userIDList.length > 0) {
            this.getEngine().TUIUser.getUserProfile({ userIDList: userIDList }).then(function (imResponse) {
                var profileList = imResponse.data || [];
                profileList.forEach(function (profile) {
                    var userID = profile.userID, nick = profile.nick;
                    var showName = nick || userID;
                    _this.userShowNameMap.set(userID, showName);
                });
            })["catch"](function () {
                // 请求出错时捕获异常，避免阻塞代码执行流程
            });
        }
    };
    MessageHandler.prototype.substringByLength = function (str, len) {
        if (len === void 0) { len = 12; }
        return str.length > len ? str.slice(0, len) + "..." : str;
    };
    MessageHandler.prototype.isOldUIKit = function (target) {
        var _a;
        var index = target.lastIndexOf('.');
        var flag = target.slice(0, index + 1);
        return (_a = this.t(target)) === null || _a === void 0 ? void 0 : _a.startsWith(flag);
    };
    return MessageHandler;
}());
exports["default"] = MessageHandler;
