"use strict";
exports.__esModule = true;
var common_utils_1 = require("../utils/common-utils");
var const_1 = require("../const");
var TypingHandler = /** @class */ (function () {
    function TypingHandler(TUIChatService) {
        this.TUIChatService = TUIChatService;
        this.typingTo = '';
        this.timer = null;
    }
    TypingHandler.prototype.getEngine = function () {
        return this.TUIChatService.getEngine();
    };
    /**
     * 清除 typing 状态
     */
    TypingHandler.prototype.clearTypingStatus = function () {
        if (this.getEngine().TUIStore.getData(const_1.StoreName.CHAT, 'typingStatus')) {
            this.getEngine().TUIStore.update(const_1.StoreName.CHAT, 'typingStatus', false);
        }
        this.timer && clearTimeout(this.timer);
        this.timer = null;
    };
    /**
     * 处理最后一条消息
     * @param { Message } lastMessage 最后一条消息
     */
    TypingHandler.prototype.handleLastMessage = function (lastMessage) {
        var _this = this;
        var getEngine = this.getEngine();
        var currentTypingStatus = getEngine.TUIStore.getData(const_1.StoreName.CHAT, 'typingStatus');
        if (lastMessage.type === this.getEngine().TYPES.MSG_CUSTOM && lastMessage.flow === 'in') {
            var typingMessage = common_utils_1.JSONToObject(lastMessage.payload.data);
            if (typingMessage.businessID === const_1.typingConfig.BUSINESS_ID) {
                var typingStatus = typingMessage.typingStatus, userAction = typingMessage.userAction;
                if (typingStatus === const_1.typingConfig.STATUS_START || userAction === const_1.typingConfig.ACTION_START_ID) {
                    if (currentTypingStatus) {
                        this.timer && clearTimeout(this.timer);
                        this.timer = null;
                    }
                    else {
                        getEngine.TUIStore.update(const_1.StoreName.CHAT, 'typingStatus', true);
                    }
                    this.timer = setTimeout(function () {
                        _this.clearTypingStatus();
                    }, 30 * 1000);
                    return getEngine.TUIStore.getData(const_1.StoreName.CHAT, 'typingStatus');
                }
                if (typingStatus === const_1.typingConfig.STATUS_END || userAction === const_1.typingConfig.ACTION_END_ID) {
                    this.clearTypingStatus();
                }
            }
        }
        return undefined;
    };
    /**
     * 用于过滤 messageList
     * @param messageList 要进行更新的 messageList
     */
    TypingHandler.prototype.filterTypingMessage = function (messageList) {
        var _this = this;
        if (messageList === void 0) { messageList = []; }
        if (messageList.length === 0) {
            return [];
        }
        var enableTyping = this.getEngine().TUIStore.getData(const_1.StoreName.APP, 'enableTyping');
        // 开启了正在输入功能时才处理从其他端收到的正输入消息
        if (enableTyping) {
            this.handleLastMessage(messageList[messageList.length - 1]);
        }
        return messageList.filter(function (item) {
            if (item.type === _this.getEngine().TYPES.MSG_CUSTOM) {
                var typingMessage = common_utils_1.JSONToObject(item.payload.data);
                if (typingMessage.businessID !== const_1.typingConfig.BUSINESS_ID) {
                    return true;
                }
                return false;
            }
            return true;
        });
    };
    /**
     * 私有方法, 创建 typing 消息体
     * @param { number } status 1: 正在输入 0: 输入完成, 默认: 0
     * @param { string } to 接收方 ID
     */
    TypingHandler.prototype.createTypingMessage = function (status, to) {
        if (status === void 0) { status = const_1.typingConfig.STATUS_END; }
        if (to === void 0) { to = ''; }
        var BUSINESS_ID = const_1.typingConfig.BUSINESS_ID, STATUS_START = const_1.typingConfig.STATUS_START, VERSION = const_1.typingConfig.VERSION, ACTION_START_ID = const_1.typingConfig.ACTION_START_ID, ACTION_END_ID = const_1.typingConfig.ACTION_END_ID, ACTION_START = const_1.typingConfig.ACTION_START, ACTION_END = const_1.typingConfig.ACTION_END, NEED_TYPING = const_1.typingConfig.NEED_TYPING;
        var options = {
            to: to,
            conversationType: this.getEngine().TYPES.CONV_C2C,
            payload: {
                data: JSON.stringify({
                    businessID: BUSINESS_ID,
                    typingStatus: status,
                    version: VERSION,
                    userAction: status === STATUS_START ? ACTION_START_ID : ACTION_END_ID,
                    actionParam: status === STATUS_START ? ACTION_START : ACTION_END
                }),
                description: '',
                extension: ''
            },
            cloudCustomData: JSON.stringify({
                messageFeature: {
                    needTyping: NEED_TYPING,
                    version: VERSION
                }
            })
        };
        return options;
    };
    /**
     * 发送 typing 消息
     * @param { boolean } status true: 正在输入 false: 输入完成 默认: false
     * @param { string } to 接收方 ID
     */
    TypingHandler.prototype.sendTyping = function (status, to) {
        if (status === void 0) { status = false; }
        if (to === void 0) { to = ''; }
        if (status) {
            this.typingTo = to;
            var typingMessage = this.createTypingMessage(const_1.typingConfig.STATUS_START, to);
            this.getEngine().TUIChat.sendCustomMessage(typingMessage, { onlineUserOnly: true });
        }
        else {
            this.sendTypingEnd();
        }
    };
    /**
     * 发送 typing 结束消息
     */
    TypingHandler.prototype.sendTypingEnd = function () {
        if (this.typingTo) {
            var typingMessage = this.createTypingMessage(const_1.typingConfig.STATUS_END, this.typingTo);
            this.getEngine().TUIChat.sendCustomMessage(typingMessage, { onlineUserOnly: true });
        }
        this.typingTo = '';
    };
    return TypingHandler;
}());
exports["default"] = TypingHandler;
