"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
exports.__esModule = true;
var message_1 = require("../../model/message");
var config_1 = require("../../config");
var ChatStore = /** @class */ (function () {
    function ChatStore() {
        this.defaultStore = {
            messageList: [],
            isCompleted: false,
            nextReqMessageID: '',
            quoteMessage: {},
            newMessageList: [],
            typingStatus: false,
            messageSource: undefined,
            translateTextInfo: undefined,
            voiceToTextInfo: undefined,
            userInfo: {},
            cacheMap: new Map()
        };
        this.store = {
            messageList: [],
            isCompleted: false,
            nextReqMessageID: '',
            quoteMessage: {},
            newMessageList: [],
            typingStatus: false,
            messageSource: undefined,
            translateTextInfo: undefined,
            voiceToTextInfo: undefined,
            cacheMap: new Map(),
            userInfo: {}
        };
    }
    ChatStore.prototype.update = function (key, data) {
        switch (key) {
            case 'messageList':
                this.updateMessageList(data);
                break;
            case 'translateTextInfo':
                this.updateTranslateTextInfo(data);
                break;
            case 'voiceToTextInfo':
                this.updateVoiceToTextInfo(data);
                break;
            default:
                this.store[key] = data;
        }
    };
    ChatStore.prototype.getData = function (key) {
        return this.store[key];
    };
    ChatStore.prototype.getModel = function (messageID) {
        return this.store.messageList.find(function (message) { return message.ID === messageID; });
    };
    ChatStore.prototype.reset = function (keyList) {
        var _this = this;
        if (keyList === void 0) { keyList = []; }
        var resetkeyList = keyList.filter(function (key) { return !config_1.CHAT_IGNORE_KEYS.includes(key); });
        this.store = __assign(__assign(__assign({}, this.defaultStore), this.store), resetkeyList === null || resetkeyList === void 0 ? void 0 : resetkeyList.reduce(function (acc, key) {
            var _a;
            return (__assign(__assign({}, acc), (_a = {}, _a[key] = _this.defaultStore[key], _a)));
        }, {}));
    };
    ChatStore.prototype.updateMessageList = function (list) {
        var _this = this;
        var toBeUpdatedList = [];
        list.forEach(function (item) {
            var messageModel = item;
            if (!(item instanceof message_1["default"])) {
                messageModel = _this.getModel(item.ID);
                if (messageModel) {
                    messageModel.updateProperties(item);
                }
                else {
                    messageModel = new message_1["default"](item);
                }
            }
            toBeUpdatedList.push(messageModel);
        });
        this.store.messageList = toBeUpdatedList;
    };
    ChatStore.prototype.updateTranslateTextInfo = function (data) {
        this.updateBykey('translateTextInfo', data);
    };
    ChatStore.prototype.updateVoiceToTextInfo = function (data) {
        this.updateBykey('voiceToTextInfo', data);
    };
    ChatStore.prototype.updateBykey = function (key, data) {
        var conversationID = data.conversationID, messageID = data.messageID, _a = data.visible, visible = _a === void 0 ? false : _a;
        if (!this.store[key]) {
            this.store[key] = new Map();
        }
        if (!this.store[key].has(conversationID)) {
            this.store[key].set(conversationID, []);
        }
        var list = this.store[key].get(conversationID) || [];
        var isAdded = true;
        for (var i = 0; i < list.length; i++) {
            if (list[i].messageID === messageID) {
                list[i].visible = visible;
                isAdded = false;
                break;
            }
        }
        if (isAdded) {
            list.push({ messageID: messageID, visible: visible });
        }
        this.store[key].set(conversationID, list);
    };
    return ChatStore;
}());
exports["default"] = ChatStore;
