import type { ISearchStore } from '../../interface/store';
import type { SEARCH_TYPE } from '../../type';

export default class SearchStore implements ISearchStore {
  public store: {
    currentSearchInputValue: {
      value: string;
      searchType: SEARCH_TYPE;
    };
    currentSearchMessageType: {
      value: {
        key: string;
        label: string;
        value: string | string[];
      };
      searchType: SEARCH_TYPE;
    };
    currentSearchMessageTime: {
      value: {
        key: string;
        label: string;
        value: {
          timePosition: number;
          timePeriod: number;
        };
      };
      searchType: SEARCH_TYPE;
    };
    currentSearchingStatus: {
      isSearching: boolean;
      searchType: string;
    };
    isShowInConversationSearch: boolean;
    [key: string]: any;
  };

  public defaultStore = {
    currentSearchInputValue: {
      value: '',
      searchType: 'global',
    },
    currentSearchMessageType: {
      value: {
        key: '',
        label: '',
        value: '',
      },
      searchType: 'global',
    },
    currentSearchMessageTime: {
      value: {
        key: '',
        label: '',
        value: {
          timePosition: 0,
          timePeriod: 0,
        },
      },
      searchType: 'global',
    },
    currentSearchingStatus: {
      isSearching: false,
      searchType: 'global',
    },
    isShowInConversationSearch: false,
  } as any;

  constructor() {
    this.store = {
      currentSearchInputValue: {
        value: '',
        searchType: 'global',
      },
      currentSearchMessageType: {
        value: {
          key: '',
          label: '',
          value: '',
        },
        searchType: 'global',
      },
      currentSearchMessageTime: {
        value: {
          key: '',
          label: '',
          value: {
            timePosition: 0,
            timePeriod: 0,
          },
        },
        searchType: 'global',
      },
      currentSearchingStatus: {
        isSearching: false,
        searchType: 'global',
      },
      isShowInConversationSearch: false,
    };
  }

  update(key: string, data: any): void {
    this.store[key] = data;
  }

  getData(key: string) {
    return this.store[key];
  }

  reset(keyList: string[] = []) {
    this.store = {
      ...this.defaultStore,
      ...this.store,
      ...keyList?.reduce((acc, key) => ({ ...acc, [key]: this.defaultStore[key] }), {}),
    };
  }
}
